graph_endorsement = {"MAIN_TABLE": "EN_AVAL_INSTITUCION",
                     "CHECKPOINT": {"DB": "__INSTITULAC__", "KEYS": ["COD_AVAL_INSTITUCION"]},
                     "SCHEMA_VERSION": 0.1,
                     "GRAPH": [{"EN_AVAL_INSTITUCION": None}]}