##
# product fields
##

product_fields = {}
product_fields["EN_PRODUCTO"] = {"alias": "product"}
product_fields["EN_PRODUCTO"]["fields"] = {
}

product_fields["EN_INSTITUCION"] = {"alias": "institution"}
product_fields["EN_INSTITUCION"]["fields"] = {
}

product_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
product_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

product_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
product_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

product_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
product_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

product_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
product_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

product_fields["EN_MUNICIPIO"] = {"alias": "city"}
product_fields["EN_MUNICIPIO"]["fields"] = {
}

product_fields["EN_PROYECTO_GR"] = {"alias": ""}
product_fields["EN_PROYECTO_GR"]["fields"] = {
}

product_fields["EN_PRODUCTO_GR"] = {"alias": "", }
product_fields["EN_PRODUCTO_GR"]["fields"] = {}

product_fields["EN_TIPO_PRODUCTO"] = {"alias": "product_type"}
product_fields["EN_TIPO_PRODUCTO"]["fields"] = {
}

product_fields["EN_PROYECTO"] = {"alias": "project"}
product_fields["EN_PROYECTO"]["fields"] = {
}

product_fields["EN_PROD_TECNICA"] = {
    "alias": "technical", "sub_section": "details"}
product_fields["EN_PROD_TECNICA"]["fields"] = {
}

product_fields["EN_PATENTE"] = {"alias": "patent", "sub_section": "details"}
product_fields["EN_PATENTE"]["fields"] = {
}

product_fields["EN_PROD_TECNOLOGICO"] = {
    "alias": "tech_product", "sub_section": "details"}
product_fields["EN_PROD_TECNOLOGICO"]["fields"] = {
}

product_fields["EN_SECRETO_INDUSTRIAL"] = {
    "alias": "industrial_secret", "sub_section": "details"}
product_fields["EN_SECRETO_INDUSTRIAL"]["fields"] = {
}

product_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software", "sub_section": "details"}
product_fields["EN_PROD_SOFTWARE"]["fields"] = {
}


product_fields["EN_REGISTRO"] = {"alias": "register", "sub_section": "details"}
product_fields["EN_REGISTRO"]["fields"] = {
}

product_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
product_fields["EN_PROD_NORMA"]["fields"] = {
}

product_fields["EN_PROD_VEGETAL"] = {
    "alias": "plant_product", "sub_section": "details"}
product_fields["EN_PROD_VEGETAL"]["fields"] = {
}

product_fields["EN_PROD_ARTISTICA"] = {
    "alias": "prod_art", "sub_section": "details"}
product_fields["EN_PROD_ARTISTICA"]["fields"] = {
}

product_fields["EN_PROD_ARTISTICA_DETALLE"] = {
    "alias": "prod_art_detail", "sub_section": "details"}
product_fields["EN_PROD_ARTISTICA_DETALLE"]["fields"] = {
}

product_fields["EN_PROD_OBRA_ARTISTICA"] = {
    "alias": "prod_artwork", "sub_section": "details"}
product_fields["EN_PROD_OBRA_ARTISTICA"]["fields"] = {
}

product_fields["EN_TESIS_ORIENTADA"] = {
    "alias": "oriented_thesis", "sub_section": "details"}
product_fields["EN_TESIS_ORIENTADA"]["fields"] = {
}

product_fields["EN_PROD_AUDIOVISUAL"] = {
    "alias": "audiovisual", "sub_section": "details"}
product_fields["EN_PROD_AUDIOVISUAL"]["fields"] = {
}

product_fields["EN_PROD_PARTITURA"] = {
    "alias": "music_sheet", "sub_section": "details"}
product_fields["EN_PROD_PARTITURA"]["fields"] = {
}

product_fields["EN_PROD_CAPITULO_LIBRO"] = {
    "alias": "book_chapter", "sub_section": "details"}
product_fields["EN_PROD_CAPITULO_LIBRO"]["fields"] = {
}

product_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
product_fields["EN_PROD_NORMA"]["fields"] = {
}
product_fields["EN_PROD_CURSO"] = {"alias": "course", "sub_section": "details"}
product_fields["EN_PROD_CURSO"]["fields"] = {
}
product_fields["EN_PROD_CAP_MEMORIA"] = {
    "alias": "memory_chapter", "sub_section": "details"}
product_fields["EN_PROD_CAP_MEMORIA"]["fields"] = {
}


product_fields["EN_PROD_ARTICULO"] = {
    "alias": "article", "sub_section": "details"}
product_fields["EN_PROD_ARTICULO"]["fields"] = {
}
product_fields["EN_LIBRO"] = {"alias": "book", "sub_section": "details"}
product_fields["EN_LIBRO"]["fields"] = {
}

product_fields["EN_REVISTA"] = {"alias": "journal", "sub_section": "details"}
product_fields["EN_REVISTA"]["fields"] = {
}

product_fields["EN_REVISTA_OTRA"] = {
    "alias": "journal_others", "sub_section": "details"}
product_fields["EN_REVISTA_OTRA"]["fields"] = {
}

product_fields["EN_EDITORIAL"] = {
    "alias": "editorial", "sub_section": "details"}
product_fields["EN_EDITORIAL"]["fields"] = {
}

product_fields["EN_EDITORIAL_OTRO"] = {
    "alias": "editorial_others", "sub_section": "details"}
product_fields["EN_EDITORIAL_OTRO"]["fields"] = {
}

product_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
product_fields["EN_SECTOR_APLICACION"]["fields"] = {
}
product_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
product_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

product_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
product_fields["EN_NIVEL_FORMACION"]["fields"] = {
}

product_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
product_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}
product_fields["EN_PAIS"] = {"alias": "country"}
product_fields["EN_PAIS"]["fields"] = {
}
product_fields["EN_IDIOMA"] = {"alias": "language"}
product_fields["EN_IDIOMA"]["fields"] = {
}

product_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
product_fields["EN_DEPARTAMENTO"]["fields"] = {
}

product_fields["EN_LIBRO_OTRO"] = {"alias": "book_other"}
product_fields["EN_LIBRO_OTRO"]["fields"] = {
}
product_fields["EN_EVENTO"] = {"alias": "event", "sub_section": "details"}
product_fields["EN_EVENTO"]["fields"] = {
}

product_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
product_fields["EN_COMUNIDAD"]["fields"] = {
}
product_fields["EN_RED"] = {"alias": "network"}
product_fields["EN_RED"]["fields"] = {
}
