##
# event fields
##
event_fields = {}
event_fields["EN_RED"] = {"alias": "network"}
event_fields["EN_RED"]["fields"] = {
}

event_fields["EN_EVENTO"] = {"alias": "event"}
event_fields["EN_EVENTO"]["fields"] = {
}

event_fields["EN_INSTITUCION"] = {"alias": "institution"}
event_fields["EN_INSTITUCION"]["fields"] = {
}
event_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
event_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}


event_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
event_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

event_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
event_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

event_fields["EN_COMUNIDAD"] = {"alias": "community", "sub_section": "details"}
event_fields["EN_COMUNIDAD"]["fields"] = {
}
event_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
event_fields["EN_PRODUCTO"]["fields"] = {
}

event_fields["EN_MUNICIPIO"] = {"alias": "city"}
event_fields["EN_MUNICIPIO"]["fields"] = {
}
event_fields["EN_PROYECTO"] = {"alias": "project"}
event_fields["EN_PROYECTO"]["fields"] = {
}

event_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
event_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

event_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
event_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

event_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
event_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

event_fields["EN_PAIS"] = {"alias": "country"}
event_fields["EN_PAIS"]["fields"] = {
}

event_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
event_fields["EN_SECTOR_APLICACION"]["fields"] = {
}


event_fields["EN_TIPO_EVENTO"] = {
    "alias": "type"}
event_fields["EN_TIPO_EVENTO"]["fields"] = {
}
