
##
# project fields
##
project_fields = {}
project_fields["EN_PROYECTO"] = {"alias": "project"}
project_fields["EN_PROYECTO"]["fields"] = {
}

project_fields["EN_INSTITUCION"] = {"alias": "institution"}
project_fields["EN_INSTITUCION"]["fields"] = {
}
project_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
project_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

#project_fields["RE_PROYECTO_INSTITUCION"] = {"alias": "institutions"}
# project_fields["RE_PROYECTO_INSTITUCION"]["fields"] = {
# }

project_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
project_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

project_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
project_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

project_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
project_fields["EN_COMUNIDAD"]["fields"] = {
}
project_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
project_fields["EN_PRODUCTO"]["fields"] = {
}

project_fields["EN_MUNICIPIO"] = {"alias": "city"}
project_fields["EN_MUNICIPIO"]["fields"] = {
}

project_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
project_fields["EN_DEPARTAMENTO"]["fields"] = {
}

project_fields["EN_PAIS"] = {"alias": "country"}
project_fields["EN_PAIS"]["fields"] = {
}

project_fields["EN_PROYECTO"] = {"alias": "project"}
project_fields["EN_PROYECTO"]["fields"] = {
}

project_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
project_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

project_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
project_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

project_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
project_fields["EN_NIVEL_FORMACION"]["fields"] = {
}

project_fields["EN_TIPO_FINANCIACION"] = {
    "alias": "funding", "sub_section": "details"}
project_fields["EN_TIPO_FINANCIACION"]["fields"] = {
}

project_fields["EN_EVENTO"] = {"alias": "event", "sub_section": "details"}
project_fields["EN_EVENTO"]["fields"] = {
}


project_fields["EN_RED"] = {"alias": "network"}
project_fields["EN_RED"]["fields"] = {
}
