
##
# networks fields
##
network_fields = {}
network_fields["EN_RED"] = {"alias": "network"}
network_fields["EN_RED"]["fields"] = {
}

network_fields["EN_INSTITUCION"] = {"alias": "institution"}
network_fields["EN_INSTITUCION"]["fields"] = {
}
network_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
network_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

network_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
network_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

network_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
network_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

network_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
network_fields["EN_COMUNIDAD"]["fields"] = {
}
network_fields["EN_PRODUCTO"] = {"alias": "product"}
network_fields["EN_PRODUCTO"]["fields"] = {
}

network_fields["EN_MUNICIPIO"] = {"alias": "city"}
network_fields["EN_MUNICIPIO"]["fields"] = {
}

network_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
network_fields["EN_DEPARTAMENTO"]["fields"] = {
}

network_fields["EN_PAIS"] = {"alias": "country"}
network_fields["EN_PAIS"]["fields"] = {
}

network_fields["EN_PROYECTO"] = {"alias": "project"}
network_fields["EN_PROYECTO"]["fields"] = {
}

network_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
network_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

network_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
network_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

network_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
network_fields["EN_NIVEL_FORMACION"]["fields"] = {
}
