##
# patent fields
##
patent_fields = {}
patent_fields["EN_PATENTE"] = {"alias": "patent"}
patent_fields["EN_PATENTE"]["fields"] = {
}

patent_fields["EN_EVENTO"] = {"alias": "event"}
patent_fields["EN_EVENTO"]["fields"] = {
}

patent_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
patent_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

patent_fields["EN_INSTITUCION"] = {"alias": "institution"}
patent_fields["EN_INSTITUCION"]["fields"] = {
}
patent_fields["EN_INSTITUCION/PATENTADORA"] = {
    "alias": "patenting_institution"}
patent_fields["EN_INSTITUCION/PATENTADORA"]["fields"] = {
}
patent_fields["EN_INSTITUCION/EXPLOTADORA"] = {
    "alias": "operating_institution"}
patent_fields["EN_INSTITUCION/EXPLOTADORA"]["fields"] = {
}

patent_fields["EN_PROD_EMPRESA_ID"] = {"alias": "company"}
patent_fields["EN_PROD_EMPRESA_ID"]["fields"] = {
}


patent_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
patent_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

patent_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
patent_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

patent_fields["EN_COMUNIDAD"] = {
    "alias": "community",
    "sub_section": "details"}
patent_fields["EN_COMUNIDAD"]["fields"] = {
}
patent_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
patent_fields["EN_PRODUCTO"]["fields"] = {
}

patent_fields["EN_PROD_TECNICA"] = {
    "alias": "technical",
    "sub_section": "details"}
patent_fields["EN_PROD_TECNICA"]["fields"] = {
}

patent_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software",
    "sub_section": "details"}
patent_fields["EN_PROD_SOFTWARE"]["fields"] = {
}

patent_fields["EN_MUNICIPIO"] = {"alias": "city"}
patent_fields["EN_MUNICIPIO"]["fields"] = {
}
patent_fields["EN_PROYECTO"] = {"alias": "project"}
patent_fields["EN_PROYECTO"]["fields"] = {
}

patent_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
patent_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

patent_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
patent_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

patent_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
patent_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

patent_fields["EN_PAIS"] = {"alias": "country"}
patent_fields["EN_PAIS"]["fields"] = {
}

patent_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
patent_fields["EN_SECTOR_APLICACION"]["fields"] = {
}

patent_fields["EN_TIPO_EVENTO"] = {
    "alias": "type"}
patent_fields["EN_TIPO_EVENTO"]["fields"] = {
}

patent_fields["EN_PROD_TECNOLOGICO"] = {
    "alias": "technological_product", "sub_section": "details"}
patent_fields["EN_PROD_TECNOLOGICO"]["fields"] = {
}

patent_fields["EN_SECRETO_INDUSTRIAL"] = {
    "alias": "industrial_secret", "sub_section": "details"}
patent_fields["EN_SECRETO_INDUSTRIAL"]["fields"] = {
}

patent_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software", "sub_section": "details"}
patent_fields["EN_PROD_SOFTWARE"]["fields"] = {
}


patent_fields["EN_REGISTRO"] = {"alias": "register", "sub_section": "details"}
patent_fields["EN_REGISTRO"]["fields"] = {
}

patent_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
patent_fields["EN_PROD_NORMA"]["fields"] = {
}

patent_fields["EN_PROD_VEGETAL"] = {
    "alias": "plant_product", "sub_section": "details"}
patent_fields["EN_PROD_VEGETAL"]["fields"] = {
}
